@@ -1,5 +1,4 @@
 import shutil
-import pytest
 from squadron.fileio import config as squadron_config
 from squadron.exceptions import UserException
 from squadron.log import log, setup_log
@@ -26,12 +25,15 @@ def test_no_config():
 def diff_dict(a, b):
     intersect = intersect_dict(a,b)
     diff = []
+    print "diff dict"
     for item in a.keys():
         if not item in intersect:
             diff.append(item)
+    print "diff dict a {}".format(diff)
     for item in b.keys():
         if not item in intersect and not item in diff:
             diff.append(item)
+    print "diff dict b {}".format(diff)
     return diff
 
 def intersect_dict(initial, diff):
@@ -39,6 +41,7 @@ def intersect_dict(initial, diff):
     for item in initial.keys():
         if(item in diff and diff[item] == initial[item]):
             intersect.append(item)
+    print "intersect({}, {}) = {}".format(initial, diff, intersect)
     return intersect
 
 def create_config(output_file, config_func):
@@ -56,6 +59,11 @@ def create_fake_config(output_file):
 
     create_config(output_file, anon)
 
+def override_func(config):
+    config.add_section('squadron')
+    for item in squadron_config.CONFIG_DEFAULTS():
+        config.set('squadron', item, 'not-default')
+
 def test_defaults():
     squadron_config.CONFIG_PATHS = ['/tmp/test_config']
     create_fake_config(squadron_config.CONFIG_PATHS[0])
@@ -68,10 +76,6 @@ def test_defaults():
 
 
 def test_overrides():
-    def override_func(config):
-        config.add_section('squadron')
-        for item in squadron_config.CONFIG_DEFAULTS():
-            config.set('squadron', item, 'not-default')
     output_file = '/tmp/test_override_config'
     squadron_config.CONFIG_PATHS = [output_file]
     create_config(output_file, override_func)
@@ -80,6 +84,16 @@ def test_overrides():
     assert(len(diff) == len(squadron_config.CONFIG_DEFAULTS()))
     assert(len(diff) > 0)
 
+def test_singleton():
+    output_file = '/tmp/test_singleton_config'
+    squadron_config.CONFIG_PATHS = [output_file]
+    create_config(output_file, override_func)
+    result = squadron_config.parse_config(log)
+    another_call = squadron_config.parse_config(log)
+    diff = diff_dict(result, another_call)
+    assert(result == another_call)
+    assert(len(diff) == 0)
+
 def test_logging(tmpdir):
     tmpdir = str(tmpdir)
     log_config_template = os.path.join(test_path, 'log.config')
